@@ -5,10 +5,11 @@
 
 .. module:: cloud_rain
    :platform: Unix, Windows
-   :synopsis: Provides :ref:`PseudoNetCDF` file interfaces for CAMx cloud/rain files.
+   :synopsis: Provides :ref:`PseudoNetCDF` file interfaces for CAMx cloud/rain
+              files.
 .. moduleauthor:: Barron Henderson <barronh@unc.edu>
 """
-__all__=['Memmap','Transforms']
+__all__ = ['Memmap', 'Transforms']
 
 from . import Memmap
 from . import Transforms
@@ -16,7 +17,7 @@ from . import Transforms
 if __name__ == '__main__':
     from PseudoNetCDF.camxfiles.cloud_rain.Memmap import cloud_rain
     from PseudoNetCDF.pncdump import pncdump_parser, \
-                                    dump_from_cmd_line
+        dump_from_cmd_line
     parser = pncdump_parser()
     (file_path, options, extra_args_dict) = parser.parse_args()
 
