@@ -1,4 +1,4 @@
-__all__=['temperature_center_time']
+__all__ = ['temperature_center_time']
 __doc__ = """
 .. _Write
 :mod:`Write` -- CAMx temperature variable transformations
@@ -7,17 +7,14 @@ __doc__ = """
 .. module:: Write
    :platform: Unix, Windows
    :synopsis: Provides :ref:`PseudoNetCDF` variable transformations
-              for CAMx temperature files.  See PseudoNetCDF.sci_var.PseudoNetCDFFile 
+              for CAMx temperature files.  See pnc.sci_var.PseudoNetCDFFile
               for interface details
 .. moduleauthor:: Barron Henderson <barronh@unc.edu>
 """
 
-from numpy import array
-
-from PseudoNetCDF.MetaNetCDF import add_derived, time_avg_new_unit
-from PseudoNetCDF.sci_var import PseudoNetCDFFile, PseudoNetCDFVariables, PseudoNetCDFVariable
+from PseudoNetCDF.MetaNetCDF import time_avg_new_unit
 from .Memmap import temperature as reg_temperature
 
+
 class temperature_center_time(time_avg_new_unit):
-    __reader__=reg_temperature
-    
+    __reader__ = reg_temperature
