@@ -5,11 +5,11 @@ __doc__ = """
 
 .. module:: vertical_diffusivity
    :platform: Unix, Windows
-   :synopsis: Provides :ref:`PseudoNetCDF` memory map and random access read 
+   :synopsis: Provides :ref:`PseudoNetCDF` memory map and random access read
    based file interfaces for CAMx vertical diffusivity files.
 .. moduleauthor:: Barron Henderson <barronh@unc.edu>
 """
-__all__=['Memmap','Read','Transforms','Write']
+__all__ = ['Memmap', 'Read', 'Transforms', 'Write']
 
 from . import Memmap
 from . import Read
@@ -17,12 +17,13 @@ from . import Write
 from . import Transforms
 
 if __name__ == '__main__':
-    from PseudoNetCDF.camxfiles.vertical_diffusivity.Memmap import vertical_diffusivity
-    from PseudoNetCDF.pncdump import pncdump_parser, \
-                                    dump_from_cmd_line
+    vertical_diffusivity = Memmap.vertical_diffusivity
+    from PseudoNetCDF.pncdump import pncdump_parser, dump_from_cmd_line
     parser = pncdump_parser()
     parser.add_argument("cols", int)
     parser.add_argument("rows", int)
     (file_path, options, extra_args_dict) = parser.parse_args()
 
-    dump_from_cmd_line(file_path, options, lambda path: vertical_diffusivity(path, **extra_args_dict))
+    dump_from_cmd_line(file_path, options,
+                       lambda path: vertical_diffusivity(path,
+                                                         **extra_args_dict))
