@@ -3,7 +3,7 @@ import os
 from collections import OrderedDict
 import numpy as np
 from PseudoNetCDF.sci_var import PseudoNetCDFVariables
-from ._bpch import _general_header_type, bpch as oldbpch, bpch_base
+from ._bpch import _general_header_type, bpch1 as oldbpch, bpch_base
 import unittest
 
 
@@ -209,7 +209,7 @@ class gcvar(object):
 
 class bpch2(bpch_base):
     @classmethod
-    def isMine(cls, path):
+    def isMine(cls, path, *args, **kwds):
         isbpch = oldbpch.isMine(path)
         if not isbpch:
             return False
@@ -220,25 +220,20 @@ class bpch2(bpch_base):
         except Exception:
             return True
 
-    def ij2ll(self, i, j):
-        """
-        i, j to center lon, lat
-        """
-        lat = np.asarray(self.variables['latitude'])
-        lon = np.asarray(self.variables['longitude'])
-        return lon[i], lat[j]
+    @classmethod
+    def from_ncf(cls, infile):
+        outf = bpch_base()
+        for pk in infile.ncattrs():
+            pv = getattr(infile, pk)
+            setattr(outf, pk, pv)
 
-    def ll2ij(self, lon, lat):
-        """
-        lon and lat may be scalars or vectors, but matrices will crash
-        """
-        late = np.asarray(self.variables['latitude_bounds'])
-        lone = np.asarray(self.variables['longitude_bounds'])
-        inlon = (lon >= lone[:, 0, None]) & (lon < lone[:, 1, None])
-        inlat = (lat >= late[:, 0, None]) & (lat < late[:, 1, None])
-        i = inlon.argmax(0)
-        j = inlat.argmax(0)
-        return i, j
+        for dk, dv in infile.dimensions.items():
+            outf.copyDimension(dv, key=dk)
+
+        for vk, vv in infile.variables.items():
+            outf.copyVariable(vv, key=vk)
+
+        return outf
 
     def __init__(self, path, nogroup=False, noscale=False,
                  vertgrid='GEOS-5-REDUCED'):
@@ -400,7 +395,7 @@ class TestMemmaps(unittest.TestCase):
         orig = open(self.bpchpath, 'rb').read()
         new = open(self.bpchpath + '.check', 'rb').read()
         assert(orig == new)
-        os.remove(self.bpchpath+'.check')
+        os.remove(self.bpchpath + '.check')
 
     def testBPCH2(self):
         bpchfile = bpch2(self.bpchpath)
