@@ -1,2 +1,2 @@
 __all__ = ['ffi1001']
-import ffi1001
+from . import ffi1001
